@@ -47,12 +47,14 @@ setClass("AllModelClass",
                         SLOW.IND='integer',
                         collectLL='numeric',
                         TOL='numeric',
+                        lrPars='S4',
+                        exploratory='logical',
                         'VIRTUAL'),
              validity = function(object) return(TRUE)
 )
 
 #------------------------------------------------------------------------------
-#' Class "ExploratoryClass"
+#' Class "SingleGroupClass"
 #'
 #' Defines the object returned from \code{\link{mirt}} when model is exploratory.
 #'
@@ -85,118 +87,46 @@ setClass("AllModelClass",
 #'     \item{\code{converge}:}{Object of class \code{"numeric"}, convergence diagnostic }
 #'     \item{\code{quadpts}:}{Object of class \code{"numeric"}, number of quadrature points }
 #'     \item{\code{esttype}:}{Object of class \code{"character"}, indicates whether estimation was 'EM' or 'MHRM'}
-#'     \item{\code{null.mod}:}{Object of class \code{"ExploratoryClass"}, null model}
+#'     \item{\code{null.mod}:}{Object of class \code{"SingleGroupClass"}, null model}
 #'     \item{\code{Target}:}{Object of class \code{"numeric"}, dummy rotation matrix}
 #'     \item{\code{condnum}:}{Object of class \code{"numeric"}, condition number of information matrix}
-#'     \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes 
+#'     \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes
 #'       second-order test}
 #'     \item{\code{bfactor}:}{Object of class \code{"list"}, an empty list}
 #'     \item{\code{infomethod}:}{Object of class \code{"character"}, indiciates which information estimation method was used}
 #'     \item{\code{TOL}:}{Object of class \code{"numeric"}, tollerence stopping criteria}
 #'     \item{\code{CUSTOM.IND}:}{Object of class \code{"integer"}, an internal index}
 #'     \item{\code{SLOW.IND}:}{Object of class \code{"integer"}, an internal index}
+#'     \item{\code{random}:}{Object of class \code{"list"}, typicall null, except for internal mixed model usage}
+#'     \item{\code{exploratory}:}{Object of class \code{"logical"}, indicates whether model contains
+#'       slopes that should be rotated}
 #'     \item{\code{Call}:}{Object of class \code{"call"}, call }
 #' }
 #' @section Methods:
 #'
 #' \describe{
-#'     \item{anova}{\code{signature(object = "ExploratoryClass")}}
-#'     \item{coef}{\code{signature(object = "ExploratoryClass")}}
-#'     \item{plot}{\code{signature(x = "ExploratoryClass", y = "missing")}}
-#'     \item{print}{\code{signature(x = "ExploratoryClass")} }
-#'     \item{residuals}{\code{signature(object = "ExploratoryClass")}}
-#'     \item{show}{\code{signature(object = "ExploratoryClass")} }
-#'     \item{summary}{\code{signature(object = "ExploratoryClass")}}
+#'     \item{anova}{\code{signature(object = "SingleGroupClass")}}
+#'     \item{coef}{\code{signature(object = "SingleGroupClass")}}
+#'     \item{plot}{\code{signature(x = "SingleGroupClass", y = "missing")}}
+#'     \item{print}{\code{signature(x = "SingleGroupClass")} }
+#'     \item{residuals}{\code{signature(object = "SingleGroupClass")}}
+#'     \item{show}{\code{signature(object = "SingleGroupClass")} }
+#'     \item{summary}{\code{signature(object = "SingleGroupClass")}}
 #' }
 #'
-#' @name ExploratoryClass-class
-#' @rdname ExploratoryClass-class
-#' @exportClass ExploratoryClass
+#' @name SingleGroupClass-class
+#' @rdname SingleGroupClass-class
+#' @exportClass SingleGroupClass
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @keywords classes
 # @examples
 setClass(
-    Class = 'ExploratoryClass', contains = 'AllModelClass',
+    Class = 'SingleGroupClass', contains = 'AllModelClass',
     representation = representation(Pl='numeric',
                                     Target='numeric',
                                     rotate='character',
-                                    bfactor='list'),
-    validity = function(object) return(TRUE)
-)
-
-#------------------------------------------------------------------------------
-#' Class "ConfirmatoryClass"
-#'
-#' Defines the object returned from \code{\link{bfactor}} and \code{\link{mirt}}
-#' when the estimated model is confirmatory.
-#'
-#' @section Slots:
-#'
-#' \describe{
-#'     \item{\code{Data}:}{Object of class \code{"list"}, contains various data matricies and properties }
-#'     \item{\code{iter}:}{Object of class \code{"numeric"}, number of iterations  }
-#'     \item{\code{pars}:}{Object of class \code{"list"}, estimated parameter objects list }
-#'     \item{\code{shortpars}:}{Object of class \code{"numeric"}, unique estimated parameters}
-#'     \item{\code{model}:}{Object of class \code{"list"}, list containing original model }
-#'     \item{\code{K}:}{Object of class \code{"numeric", number of item categories}  }
-#'     \item{\code{itemloc}:}{Object of class \code{"numeric", index for tabdata}  }
-#'     \item{\code{df}:}{Object of class \code{"numeric"}, degrees of freedom }
-#'     \item{\code{AIC}:}{Object of class \code{"numeric"}, Akaike's information criteria }
-#'     \item{\code{BIC}:}{Object of class \code{"numeric"}, Bayesian information criteria }
-#'     \item{\code{G2}:}{Object of class \code{"numeric"}, G squared stat }
-#'     \item{\code{p}:}{Object of class \code{"numeric"}, p-value for G2  }
-#'     \item{\code{df}:}{Object of class \code{"numeric"}, degrees of freedom }
-#'     \item{\code{RMSEA}:}{Object of class \code{"numeric"}, root mean-square error of approximation for G2}
-#'     \item{\code{TLI}:}{Object of class \code{"numeric"}, Tucker-Lewis index for G2}
-#'     \item{\code{CFI}:}{Object of class \code{"numeric"}, CFI for G2}
-#'     \item{\code{logLik}:}{Object of class \code{"numeric"}, observed log-likelihood }
-#'     \item{\code{SElogLik}:}{Object of class \code{"numeric"}, Monte Carlo standard error for log-likelihood }
-#'     \item{\code{F}:}{Object of class \code{"matrix"}, unrotated factor loadings }
-#'     \item{\code{h2}:}{Object of class \code{"numeric"}, commonalities }
-#'     \item{\code{Theta}:}{Object of class \code{"matrix"}, ability grid }
-#'     \item{\code{Pl}:}{Object of class \code{"numeric"}, normed likelihoods for tabulated response}
-#'     \item{\code{Prior}:}{Object of class \code{"list"}, prior distribution used during estimation. Empty unless
-#'         \code{empiricalhist = TRUE}}
-#'     \item{\code{prodlist}:}{Object of class \code{"list"}, list containing product combination of factors }
-#'     \item{\code{converge}:}{Object of class \code{"numeric"}, convergence diagnostic }
-#'     \item{\code{quadpts}:}{Object of class \code{"numeric"}, number of quadrature points }
-#'     \item{\code{esttype}:}{Object of class \code{"character"}, indicates whether estimation was 'EM' or 'MHRM'}
-#'     \item{\code{random}:}{Object of class \code{"list"}, typicall null, except for internal mixed model usage}
-#'     \item{\code{null.mod}:}{Object of class \code{"ExploratoryClass"}, null model}
-#'     \item{\code{condnum}:}{Object of class \code{"numeric"}, condition number of information matrix}
-#'     \item{\code{bfactor}:}{Object of class \code{"list"}, contains information from bfactor() estimation}
-#'     \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes 
-#'       second-order test}
-#'     \item{\code{infomethod}:}{Object of class \code{"character"}, indiciates which information estimation method was used}
-#'     \item{\code{TOL}:}{Object of class \code{"numeric"}, tollerence stopping criteria}
-#'     \item{\code{CUSTOM.IND}:}{Object of class \code{"integer"}, an internal index}
-#'     \item{\code{SLOW.IND}:}{Object of class \code{"integer"}, an internal index}
-#'     \item{\code{Call}:}{Object of class \code{"call"}, call }
-#'   }
-#' @section Methods:
-#'
-#' \describe{
-#'    \item{coef}{\code{signature(object = "ConfirmatoryClass")}}
-#'    \item{print}{\code{signature(x = "ConfirmatoryClass")} }
-#'    \item{residuals}{\code{signature(object = "ConfirmatoryClass")}}
-#'    \item{show}{\code{signature(object = "ConfirmatoryClass")} }
-#'    \item{summary}{\code{signature(object = "ConfirmatoryClass")} }
-#'    \item{logLik}{\code{signature(object = "ConfirmatoryClass")} }
-#'    \item{anova}{\code{signature(object = "ConfirmatoryClass")} }
-#' }
-#'
-#' @name ConfirmatoryClass-class
-#' @rdname ConfirmatoryClass-class
-#' @exportClass ConfirmatoryClass
-#' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
-#' @keywords classes
-# @examples
-# @keywords classes
-setClass(
-    Class = 'ConfirmatoryClass', contains = 'AllModelClass',
-    representation = representation(Pl='numeric',
-                                    random='list',
-                                    bfactor='list'),
+                                    bfactor='list',
+                                    random='list'),
     validity = function(object) return(TRUE)
 )
 
@@ -237,10 +167,10 @@ setClass(
 #'    \item{\code{esttype}:}{Object of class \code{"character"}, indicates whether estimation was 'EM' or 'MHRM'}
 #'    \item{\code{constrain}:}{Object of class \code{"list"}, list of constraints}
 #'    \item{\code{invariance}:}{Object of class \code{"character"}, invariance input}
-#'    \item{\code{null.mod}:}{Object of class \code{"ExploratoryClass"}, null model}
+#'    \item{\code{null.mod}:}{Object of class \code{"SingleGroupClass"}, null model}
 #'    \item{\code{condnum}:}{Object of class \code{"numeric"}, condition number of information matrix}
 #'     \item{\code{bfactor}:}{Object of class \code{"list"}, contains information from bfactor() estimation}
-#'    \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes 
+#'    \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes
 #'       second-order test}
 #'     \item{\code{infomethod}:}{Object of class \code{"character"}, indiciates which information estimation method was used}
 #'     \item{\code{TOL}:}{Object of class \code{"numeric"}, tollerence stopping criteria}
@@ -308,14 +238,17 @@ setClass(
 #'    \item{\code{esttype}:}{Object of class \code{"character"}, indicates whether estimation was 'EM' or 'MHRM'}
 #'    \item{\code{cand.t.var}:}{Object of class \code{"numeric"}, parameter used to control the MH sampler for Theta}
 #'    \item{\code{random}:}{Object of class \code{"list"}, typicall null, except for internal mixed model usage}
-#'    \item{\code{null.mod}:}{Object of class \code{"ExploratoryClass"}, null model}
+#'    \item{\code{null.mod}:}{Object of class \code{"SingleGroupClass"}, null model}
 #'    \item{\code{condnum}:}{Object of class \code{"numeric"}, condition number of information matrix}
-#'    \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes 
+#'    \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes
 #'       second-order test}
 #'     \item{\code{infomethod}:}{Object of class \code{"character"}, indiciates which information estimation method was used}
 #'     \item{\code{TOL}:}{Object of class \code{"numeric"}, tollerence stopping criteria}
 #'     \item{\code{CUSTOM.IND}:}{Object of class \code{"integer"}, an internal index}
 #'     \item{\code{SLOW.IND}:}{Object of class \code{"integer"}, an internal index}
+#'     \item{\code{formulas}:}{Object of class \code{"list"}, list of formula}
+#'     \item{\code{covdata}:}{Object of class \code{"data.frame"}, covariate data}
+#'     \item{\code{itemdesign}:}{Object of class \code{"data.frame"}, item design data}
 #'    \item{\code{Call}:}{Object of class \code{"call"}, call }
 #'  }
 #' @section Methods:
@@ -341,7 +274,10 @@ setClass(
     Class = 'MixedClass', contains = 'AllModelClass',
     representation = representation(Pl='numeric',
                                     random='list',
-                                    cand.t.var='numeric'),
+                                    cand.t.var='numeric',
+                                    formulas='list',
+                                    covdata='data.frame',
+                                    itemdesign='data.frame'),
     validity = function(object) return(TRUE)
 )
 
@@ -381,10 +317,10 @@ setClass(
 #'    \item{\code{quadpts}:}{Object of class \code{"numeric"}, number of quadrature points }
 #'    \item{\code{esttype}:}{Object of class \code{"character"}, indicates whether estimation was 'EM' or 'MHRM'}
 #'    \item{\code{constrain}:}{Object of class \code{"list"}, list of constraints}
-#'    \item{\code{null.mod}:}{Object of class \code{"ExploratoryClass"}, null model}
+#'    \item{\code{null.mod}:}{Object of class \code{"SingleGroupClass"}, null model}
 #'    \item{\code{condnum}:}{Object of class \code{"numeric"}, condition number of information matrix}
 #'     \item{\code{bfactor}:}{Object of class \code{"list"}, contains information from bfactor() estimation}
-#'    \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes 
+#'    \item{\code{secondordertest}:}{Object of class \code{"logical"}, indicate whether information matrix passes
 #'       second-order test}
 #'     \item{\code{infomethod}:}{Object of class \code{"character"}, indiciates which information estimation method was used}
 #'     \item{\code{TOL}:}{Object of class \code{"numeric"}, tollerence stopping criteria}
