@@ -44,7 +44,8 @@
 #' @param method type of factor score estimation method. Can be expected
 #'   a-posteriori (\code{"EAP"}), Bayes modal (\code{"MAP"}), weighted likelihood estimation
 #'   (\code{"WLE"}), maximum likelihood (\code{"ML"}), or expected a-posteriori for sum scores
-#'   (\code{"EAPsum"})
+#'   (\code{"EAPsum"}). Can also be \code{"plausible"} for a single plausible value imputation for
+#'   each case, and this is equivalent to setting \code{plausible.draws = 1}
 #' @param quadpts number of quadratures to use per dimension. If not specified, a suitable
 #'   one will be created which decreases as the number of dimensions increases
 #'   (and therefore for estimates such as EAP, will be less accurate). This is determined from
@@ -70,7 +71,17 @@
 #'   \code{full.scores = TRUE})
 #' @param QMC logical; use quasi-Monte Carlo integration? If \code{quadpts} is omitted the
 #'   default number of nodes is 2000
-#' @param ... additional arguments
+#' @param custom_den a function used to define the integration density (if required). The NULL default
+#'   assumes that the multivariate normal distribution with the 'GroupPars' hyper-parameters are
+#'   used. At the minimum must be of the form:
+#'
+#'   \code{function(Theta, ...)}
+#'
+#'   where Theta is a matrix of latent trait values (will be a grid of values
+#'   if \code{method == 'EAPsum'} or \code{method == 'EAP'}, otherwise Theta will have only 1 row).
+#'   Additional arguments may included and are caught through the \code{fscores(...)} input. The
+#'   function \emph{must} return a numeric vector of density weights (one for each row in Theta)
+#' @param ... additional arguments to be passed to \code{nlm}
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @keywords factor.scores
 #' @seealso \code{\link{averageMI}}
@@ -123,12 +134,22 @@
 #' pv <- fscores(mod, plausible.draws = 5)
 #' lapply(pv, function(x) c(mean=mean(x), var=var(x), min=min(x), max=max(x)))
 #'
+#' ## define a custom_den function. EAP with a uniform prior between -3 and 3
+#' fun <- function(Theta, ...) as.numeric(dunif(Theta, min = -3, max = 3))
+#' head(fscores(mod, custom_den = fun))
+#'
+#' # custom MAP prior: standard truncated normal between 5 and -2
+#' library(msm)
+#' # need the :: scope for parallel to see the function (not require if no mirtCluster() defined)
+#' fun <- function(Theta, ...) msm::dtnorm(Theta, mean = 0, sd = 1, lower = -2, upper = 5)
+#' head(fscores(mod, custom_den = fun, method = 'MAP'))
+#'
 #'}
 fscores <- function(object, rotate = NULL, full.scores = FALSE, method = "EAP",
                     quadpts = NULL, response.pattern = NULL, plausible.draws = 0,
                     returnER = FALSE, return.acov = FALSE, mean = NULL, cov = NULL, verbose = TRUE,
                     scores.only = TRUE, full.scores.SE = FALSE, theta_lim = c(-6,6), MI = 0,
-                    QMC = FALSE, ...)
+                    QMC = FALSE, custom_den = NULL, ...)
 {
     if(!is(object, 'DiscreteClass')){
         if(QMC && is.null(quadpts)) quadpts <- 2000
@@ -136,11 +157,15 @@ fscores <- function(object, rotate = NULL, full.scores = FALSE, method = "EAP",
             quadpts <- switch(as.character(object@nfact),
                               '1'=61, '2'=31, '3'=15, '4'=9, '5'=7, 3)
     } else quadpts <- 1
+    if(method == 'plausible'){
+        plausible.draws <- 1
+        method <- 'EAP'
+    }
     ret <- fscores.internal(object=object, rotate=rotate, full.scores=full.scores, method=method,
                             quadpts=quadpts, response.pattern=response.pattern, QMC=QMC,
                             verbose=verbose, returnER=returnER, gmean=mean, gcov=cov,
                             scores.only=scores.only, theta_lim=theta_lim, MI=MI,
                             full.scores.SE=full.scores.SE, return.acov=return.acov,
-                            plausible.draws = plausible.draws, ...)
+                            plausible.draws = plausible.draws, custom_den=custom_den, ...)
     ret
 }
