@@ -5,19 +5,22 @@ setMethod(
                           quadpts = NULL, response.pattern = NULL, theta_lim, MI,
 	                      returnER = FALSE, verbose = TRUE, gmean, gcov, scores.only,
 	                      plausible.draws, full.scores.SE, return.acov = FALSE,
-                          QMC, digits=4, ...)
+                          QMC, custom_den = NULL, digits=4, ...)
 	{
+        den_fun <- mirt_dmvnorm
+        if(!is.null(custom_den)) den_fun <- custom_den
+
 	    #local functions for apply
 	    MAP <- function(ID, scores, pars, tabdata, itemloc, gp, prodlist, CUSTOM.IND,
-	                    hessian, mirtCAT, return.acov = FALSE){
+	                    hessian, mirtCAT = FALSE, return.acov = FALSE, den_fun, ...){
             if(mirtCAT){
-                estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars, patdata=tabdata[ID, ],
+                estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars, patdata=tabdata[ID, ], den_fun=den_fun,
                                     itemloc=itemloc, gp=gp, prodlist=prodlist, hessian=hessian,
-                                    CUSTOM.IND=CUSTOM.IND, ID=ID, iterlim=1, stepmax=1e-20))
+                                    CUSTOM.IND=CUSTOM.IND, ID=ID, iterlim=1, stepmax=1e-20, ...))
             } else {
-    	        estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars, patdata=tabdata[ID, ],
+    	        estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars, patdata=tabdata[ID, ], den_fun=den_fun,
     	                            itemloc=itemloc, gp=gp, prodlist=prodlist, hessian=hessian,
-                                    CUSTOM.IND=CUSTOM.IND, ID=ID, iterlim=200))
+                                    CUSTOM.IND=CUSTOM.IND, ID=ID, ...))
             }
 	        if(is(estimate, 'try-error'))
 	            return(rep(NA, ncol(scores)*2))
@@ -25,47 +28,47 @@ setMethod(
                 vcov <- try(solve(estimate$hessian))
                 if(return.acov) return(vcov)
     	        SEest <- try(sqrt(diag(vcov)))
-    	        if(is(SEest, 'try-error')) SEest <- rep(NA, ncol(scores))
             } else SEest <- rep(NA, ncol(scores))
 	        return(c(estimate$estimate, SEest))
 	    }
 	    ML <- function(ID, scores, pars, tabdata, itemloc, gp, prodlist, CUSTOM.IND,
-	                   hessian, mirtCAT, return.acov = FALSE){
+	                   hessian, return.acov = FALSE, den_fun, ...){
 	        if(any(scores[ID, ] %in% c(-Inf, Inf)))
                 return(c(scores[ID, ], rep(NA, ncol(scores))))
-            if(mirtCAT){
-                estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars,patdata=tabdata[ID, ],
-                                    itemloc=itemloc, gp=gp, prodlist=prodlist, ML=TRUE,
-                                    hessian=hessian, CUSTOM.IND=CUSTOM.IND, ID=ID, iterlim=1,
-                                    stepmax=1e-20))
-            } else {
-    	        estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars,patdata=tabdata[ID, ],
-    	                            itemloc=itemloc, gp=gp, prodlist=prodlist, ML=TRUE,
-                                    hessian=hessian, CUSTOM.IND=CUSTOM.IND, ID=ID, iterlim=200))
-            }
+            estimate <- try(nlm(MAP.mirt,scores[ID, ],pars=pars,patdata=tabdata[ID, ], den_fun=NULL,
+    	                        itemloc=itemloc, gp=gp, prodlist=prodlist, ML=TRUE,
+                                hessian=hessian, CUSTOM.IND=CUSTOM.IND, ID=ID, ...))
 	        if(is(estimate, 'try-error'))
 	            return(rep(NA, ncol(scores)*2))
+	        est <- estimate$estimate
             if(hessian){
-    	        vcov <- try(solve(estimate$hessian))
+                pick <- diag(estimate$hessian) > 0
+                if(!all(pick)){
+    	            vcov_small <- try(solve(estimate$hessian[pick,pick,drop=FALSE]))
+                    vcov <- matrix(0, length(pick), length(pick))
+                    vcov[pick,pick] <- vcov_small
+                } else vcov <- try(solve(estimate$hessian))
     	        if(return.acov) return(vcov)
     	        SEest <- try(sqrt(diag(vcov)))
-    	        if(is(SEest, 'try-error')) SEest <- rep(NA, ncol(scores))
+                if(any(SEest > 30)){
+                    est[SEest > 30] <- Inf * sign(est[SEest > 30])
+                    SEest[SEest > 30] <- NA
+                }
             } else SEest <- rep(NA, ncol(scores))
-	        return(c(estimate$estimate, SEest))
+	        return(c(est, SEest))
 	    }
 	    WLE <- function(ID, scores, pars, tabdata, itemloc, gp, prodlist, CUSTOM.IND,
-                        hessian, return.acov = FALSE){
-	        estimate <- try(nlm(gradnorm.WLE,scores[ID, ],pars=pars,patdata=tabdata[ID, ], hessian=FALSE,
-	                            itemloc=itemloc, gp=gp, prodlist=prodlist, CUSTOM.IND=CUSTOM.IND))
+	                    hessian, data, return.acov = FALSE, ...){
+	        estimate <- try(nlm(WLE.mirt, scores[ID, ], pars=pars, patdata=tabdata[ID, ],
+	                            itemloc=itemloc, gp=gp, prodlist=prodlist, data=data[ID, ],
+	                            hessian=hessian, CUSTOM.IND=CUSTOM.IND, ID=ID, ...))
 	        if(is(estimate, 'try-error'))
 	            return(rep(NA, ncol(scores)*2))
-            if(hessian){
-                TI <- 0
-                for(i in 1L:(length(itemloc)-1L))
-                    TI <- TI + iteminfo(pars[[i]], Theta=estimate$estimate)
-                if(return.acov) return(1/TI)
-    	        SEest <- 1 / sqrt(TI)
-            } else SEest <- rep(NA, ncol(scores))
+	        if(hessian){
+	            vcov <- try(solve(estimate$hessian))
+	            if(return.acov) return(vcov)
+	            SEest <- try(sqrt(diag(vcov)))
+	        } else SEest <- rep(NA, ncol(scores))
 	        return(c(estimate$estimate, SEest))
 	    }
 	    EAP <- function(ID, log_itemtrace, tabdata, ThetaShort, W, hessian, return.acov = FALSE){
@@ -98,18 +101,19 @@ setMethod(
         if(plausible.draws > 0){
             fs <- fscores(object, rotate=rotate, full.scores = TRUE, method=method,
                           quadpts = quadpts, theta_lim=theta_lim, verbose=FALSE,
-                          return.acov = FALSE, QMC=QMC, ...)
+                          return.acov = FALSE, QMC=QMC, custom_den = NULL, ...)
             fs_acov <- fscores(object, rotate = rotate, full.scores = TRUE, method=method,
                           quadpts = quadpts, theta_lim=theta_lim, verbose=FALSE,
                           scores.only=TRUE, plausible.draws=0, full.scores.SE=FALSE,
-                          return.acov = TRUE, QMC=QMC, ...)
+                          return.acov = TRUE, QMC=QMC, custom_den = NULL, ...)
             ret <- vector('list', plausible.draws)
             for(i in 1L:plausible.draws){
                 jit <- lapply(fs_acov, function(x) mirt_rmvnorm(ncol(x), sigma = x))
                 jit <- do.call(rbind, jit)
                 ret[[i]] <- fs + jit
             }
-            return(ret)
+            if(plausible.draws == 1L) return(ret[[1L]])
+            else return(ret)
         }
         if(return.acov && MI != 0)
             stop('simultaneous impute and return.acov option not supported')
@@ -135,7 +139,7 @@ setMethod(
                 ret <- fscores(newmod, rotate=rotate, full.scores=TRUE, scores.only=FALSE,
                                method=method, quadpts=quadpts, verbose=FALSE, full.scores.SE=TRUE,
                                response.pattern=NULL, return.acov=return.acov, theta_lim=theta_lim,
-                               MI=MI, mean=gmean, cov=gcov, ...)
+                               MI=MI, mean=gmean, cov=gcov, custom_den=custom_den, ...)
             } else {
                 pick <- which(!is.na(response.pattern))
                 rp <- response.pattern[,pick,drop=FALSE]
@@ -149,7 +153,7 @@ setMethod(
                 ret <- fscores(newmod, rotate=rotate, full.scores=TRUE, scores.only=FALSE,
                                method=method, quadpts=quadpts, verbose=FALSE, full.scores.SE=TRUE,
                                response.pattern=NULL, return.acov=return.acov, theta_lim=theta_lim,
-                               MI=MI, mean=gmean, cov=gcov, ...)
+                               MI=MI, mean=gmean, cov=gcov, custom_den=custom_den, ...)
                 if(return.acov) return(ret)
                 ret <- cbind(response.pattern, ret[,c(paste0('F', 1L:nfact),
                                                       paste0('SE_F', 1L:nfact)), drop=FALSE])
@@ -190,7 +194,7 @@ setMethod(
         if(method == 'EAPsum') return(EAPsum(object, full.scores=full.scores,
                                              quadpts=quadpts, gp=gp, verbose=verbose,
                                              CUSTOM.IND=CUSTOM.IND, theta_lim=theta_lim,
-                                             discrete=discrete, QMC=QMC))
+                                             discrete=discrete, QMC=QMC, den_fun=den_fun, ...))
 		theta <- as.matrix(seq(theta_lim[1L], theta_lim[2L], length.out=quadpts))
 		fulldata <- object@Data$data
 		LR <- .hasSlot(object@lrPars, 'beta')
@@ -243,7 +247,8 @@ setMethod(
                     } else thetaComb(theta,nfact)
                     if(length(prodlist) > 0L)
                         Theta <- prodterms(Theta,prodlist)
-                    W <- mirt_dmvnorm(ThetaShort,gp$gmeans,gp$gcov, quad=LR)
+                    W <- den_fun(ThetaShort, mean=gp$gmeans, sigma=gp$gcov, quad=LR, ...)
+                    W <- W/sum(W)
                 }
                 itemtrace <- computeItemtrace(pars=pars, Theta=Theta, itemloc=itemloc,
                                               CUSTOM.IND=CUSTOM.IND)
@@ -262,8 +267,9 @@ setMethod(
                 #do nothing
     		} else if(method == "MAP"){
                 tmp <- myApply(X=matrix(1L:nrow(scores)), MARGIN=1L, FUN=MAP, scores=scores, pars=pars,
-                               tabdata=tabdata, itemloc=itemloc, gp=gp, prodlist=prodlist,
-                               CUSTOM.IND=CUSTOM.IND, return.acov=return.acov, mirtCAT=mirtCAT, hessian=estHess)
+                               tabdata=tabdata, itemloc=itemloc, gp=gp, prodlist=prodlist, den_fun=den_fun,
+                               CUSTOM.IND=CUSTOM.IND, return.acov=return.acov, hessian=estHess,
+                               ...)
     		} else if(method == "ML"){
                 isna <- apply(object@Data$tabdata[,-ncol(object@Data$tabdata),drop=FALSE], 1L,
                               function(x) sum(is.na(x)))[keep]
@@ -274,16 +280,15 @@ setMethod(
                 scores[allzero,] <- -Inf
                 SEscores[allzero,] <- NA
                 tmp <- myApply(X=matrix(1L:nrow(scores)), MARGIN=1L, FUN=ML, scores=scores, pars=pars,
-                               tabdata=tabdata, itemloc=itemloc, gp=gp, prodlist=prodlist,
-                               CUSTOM.IND=CUSTOM.IND, return.acov=return.acov, mirtCAT=mirtCAT, hessian=estHess)
+                               tabdata=tabdata, itemloc=itemloc, gp=gp, prodlist=prodlist, den_fun=NULL,
+                               CUSTOM.IND=CUSTOM.IND, return.acov=return.acov, hessian=estHess,
+                               ...)
     		} else if(method == 'WLE'){
                 if(nfact > 1L)
                     stop('WLE method only supported for unidimensional models')
-                itemtrace <- computeItemtrace(pars=pars, Theta=Theta, itemloc=itemloc,
-                                              CUSTOM.IND=CUSTOM.IND)
                 tmp <- myApply(X=matrix(1L:nrow(scores)), MARGIN=1L, FUN=WLE, scores=scores, pars=pars,
                                tabdata=tabdata, itemloc=itemloc, gp=gp, prodlist=prodlist,
-                               CUSTOM.IND=CUSTOM.IND, hessian=estHess)
+                               CUSTOM.IND=CUSTOM.IND, hessian=estHess, data=object@Data$tabdata, ...)
             } else {
                 stop('method not defined')
             }
@@ -330,7 +335,7 @@ setMethod(
                     ret <- vector('list', nrow(scoremat))
                     for(i in 1L:nrow(scoremat))
                         ret[[i]] <- matrix(scoremat[i,], nfact, nfact)
-                    names(ret) <- 1:nrow(scoremat)
+                    names(ret) <- 1L:nrow(scoremat)
                     return(ret)
                 }
             }
@@ -347,7 +352,7 @@ setMethod(
                 return(ret)
             }
             r <- object@Data$Freq[[1L]]
-            T <- E <- matrix(NA, 1, ncol(scores))
+            T <- E <- matrix(NA, 1L, ncol(scores))
             for(i in 1L:nrow(scores)){
                 if(any(scores[i, ] %in% c(Inf, -Inf))) next
                 T <- rbind(T, matrix(rep(scores[i, ], r[i]), ncol=ncol(scores), byrow = TRUE))
@@ -438,7 +443,7 @@ setMethod(
             ret[[g]] <- fscores(tmp, rotate = 'CONFIRMATORY', full.scores=full.scores, method=method,
                            quadpts=quadpts, returnER=returnER, verbose=verbose, theta_lim=theta_lim,
                                 mean=gmean[[g]], cov=gcov[[g]], scores.only=FALSE, MI=MI,
-                           full.scores.SE=full.scores.SE, return.acov=return.acov, QMC=QMC)
+                           full.scores.SE=full.scores.SE, return.acov=return.acov, QMC=QMC, ...)
         }
         names(ret) <- object@Data$groupNames
         if(full.scores){
@@ -476,7 +481,7 @@ setMethod(
 
 # MAP scoring for mirt
 MAP.mirt <- function(Theta, pars, patdata, itemloc, gp, prodlist, CUSTOM.IND, ID,
-                     ML=FALSE)
+                     ML=FALSE, den_fun, ...)
 {
     Theta <- matrix(Theta, nrow=1L)
     ThetaShort <- Theta
@@ -486,11 +491,31 @@ MAP.mirt <- function(Theta, pars, patdata, itemloc, gp, prodlist, CUSTOM.IND, ID
                                   CUSTOM.IND=CUSTOM.IND)
     L <- sum(log(itemtrace)[as.logical(patdata)])
     mu <- if(is.matrix(gp$gmeans)) gp$gmeans[ID, ] else gp$gmeans
-    prior <- mirt_dmvnorm(ThetaShort, mu, gp$gcov)
+    if(!ML){
+        prior <- den_fun(ThetaShort, mean=mu, sigma=gp$gcov, ...)
+        if(prior < 1e-200) prior <- 1e-200
+    }
     L <- ifelse(ML, -L, (-1)*(L + log(prior)))
     L
 }
 
+WLE.mirt <- function(Theta, pars, patdata, itemloc, gp, prodlist, CUSTOM.IND, ID, data)
+{
+    Theta <- matrix(Theta, nrow=1L)
+    ThetaShort <- Theta
+    if(length(prodlist) > 0L)
+        Theta <- prodterms(Theta,prodlist)
+    itemtrace <- computeItemtrace(pars=pars, Theta=Theta, itemloc=itemloc,
+                                  CUSTOM.IND=CUSTOM.IND)
+    L <- sum(log(itemtrace)[as.logical(patdata)])
+    infos <- numeric(length(data))
+    for(i in 1L:length(infos)){
+        if(!is.na(data[i]))
+            infos[i] <- ItemInfo2(x=pars[[i]], Theta=Theta, total.info=TRUE)
+    }
+    return(-(log(sqrt(sum(infos))) + L))
+}
+
 gradnorm.WLE <- function(Theta, pars, patdata, itemloc, gp, prodlist, CUSTOM.IND){
     Theta <- matrix(Theta, nrow=1L)
     ThetaShort <- Theta
@@ -528,7 +553,7 @@ gradnorm.WLE <- function(Theta, pars, patdata, itemloc, gp, prodlist, CUSTOM.IND
 }
 
 EAPsum <- function(x, full.scores = FALSE, quadpts = NULL, S_X2 = FALSE, gp, verbose, CUSTOM.IND,
-                   theta_lim, discrete, QMC){
+                   theta_lim, discrete, QMC, den_fun, ...){
     calcL1 <- function(itemtrace, K, itemloc){
         J <- length(K)
         L0 <- L1 <- matrix(1, sum(K-1L) + 1L, ncol(itemtrace))
@@ -562,7 +587,7 @@ EAPsum <- function(x, full.scores = FALSE, quadpts = NULL, S_X2 = FALSE, gp, ver
         ThetaShort <- Theta <- if(QMC){
             qnorm(sfsmisc::QUnif(quadpts, min=0, max=1, p=nfact, leap = 409), sd=2)
         } else thetaComb(theta,nfact)
-        prior <- mirt_dmvnorm(Theta,gp$gmeans,gp$gcov)
+        prior <- den_fun(Theta, mean=gp$gmeans, sigma=gp$gcov, ...)
         prior <- prior/sum(prior)
         if(length(prodlist) > 0L)
             Theta <- prodterms(Theta, prodlist)
@@ -636,8 +661,9 @@ EAPsum <- function(x, full.scores = FALSE, quadpts = NULL, S_X2 = FALSE, gp, ver
         tmp <- suppressWarnings(expand.table(cbind(ret[,2L:(ncol(ret)-1L)], ret$observed)))
         pick <- 1L:x@nfact
         rxx <- apply(tmp[,pick, drop=FALSE], 2L, var) /
-            (apply(tmp[,pick, drop=FALSE], 2L, var) + apply(tmp[,pick, drop=FALSE], 2L,
+            (apply(tmp[,pick, drop=FALSE], 2L, var) + apply(tmp[,pick+x@nfact, drop=FALSE], 2L,
                                                             function(x) mean(x^2)))
+        names(rxx) <- paste0('rxx_Theta.', 1:x@nfact)
         attr(ret, 'fit') <- data.frame(df=df, X2=X2, p.X2 = pchisq(X2, df, lower.tail=FALSE),
                                        G2=G2, p.G2 = pchisq(G2, df, lower.tail=FALSE),
                                        rxx=as.list(rxx))
