@@ -45,6 +45,8 @@ randef <- function(x, ndraws = 1000, thin = 10, return.draws=FALSE){
     } else OffTerm <- matrix(0, 1, ncol(x@Data$data))
     gstructgrouppars <- ExtractGroupPars(x@pars[[J+1L]])
     CUSTOM.IND <- x@CUSTOM.IND
+    if(length(x@lrPars))
+        gstructgrouppars$gmeans <- x@lrPars@X %*% x@lrPars@beta
     for(i in 1L:20L){
         tmpTheta <- draw.thetas(theta0=tmpTheta, pars=x@pars, fulldata=x@Data$fulldata[[1L]],
                                 itemloc=x@itemloc, cand.t.var=x@cand.t.var,
