@@ -10,12 +10,12 @@ void _Estep(vector<double> &expected, vector<double> &r1vec, const vector<double
     const int nquad = prior.size();
     const int nitems = data.ncol();
     const int npat = r.size();
-    #ifdef SUPPORT_OPENMP
-    if(npat > 1)
-        omp_set_num_threads(ncores);
-    #endif
-
-    #pragma omp parallel for
+//    #ifdef SUPPORT_OPENMP
+//    if(npat > 1)
+//        omp_set_num_threads(ncores);
+//    #endif
+//
+//    #pragma omp parallel for
     for (int pat = 0; pat < npat; ++pat){
         if(r[pat] < 1e-10) continue;
         vector<double> posterior(nquad,1.0);
@@ -77,12 +77,12 @@ void _Estep2(vector<double> &expected, vector<double> &r1vec, const NumericMatri
     const int nquad = prior.ncol();
     const int nitems = data.ncol();
     const int npat = data.nrow();
-    #ifdef SUPPORT_OPENMP
-    if(npat > 1)
-        omp_set_num_threads(ncores);
-    #endif
-
-     #pragma omp parallel for
+//    #ifdef SUPPORT_OPENMP
+//    if(npat > 1)
+//        omp_set_num_threads(ncores);
+//    #endif
+//
+//     #pragma omp parallel for
      for (int pat = 0; pat < npat; ++pat){
          vector<double> posterior(nquad,1.0);
          for(int q = 0; q < nquad; ++q)
